@@ -3,31 +3,34 @@ from __future__ import absolute_import
 
 from os import path as op
 
-import py # noqa
 import pytest
 
+from pylama.config import CURDIR
+from pylama.main import DEFAULT_FORMAT, parse_options, process_paths
 
 HISTKEY = "pylama/mtimes"
 
 
-def pytest_load_initial_conftests(early_config, parser, args):
+def pytest_load_initial_conftests(early_config, *_):
     # Marks have to be registered before usage
     # to not fail with --strict command line argument
     early_config.addinivalue_line(
-        'markers',
-        'pycodestyle: Mark test as using pylama code audit tool.')
+        "markers", "pycodestyle: Mark test as using pylama code audit tool."
+    )
 
 
 def pytest_addoption(parser):
     group = parser.getgroup("general")
     group.addoption(
-        '--pylama', action='store_true',
-        help="perform some pylama code checks on .py files")
+        "--pylama",
+        action="store_true",
+        help="perform some pylama code checks on .py files",
+    )
 
 
 def pytest_sessionstart(session):
     config = session.config
-    if config.option.pylama and getattr(config, 'cache', None):
+    if config.option.pylama and getattr(config, "cache", None):
         config._pylamamtimes = config.cache.get(HISTKEY, {})
 
 
@@ -39,24 +42,26 @@ def pytest_sessionfinish(session):
 
 def pytest_collect_file(path, parent):
     config = parent.config
-    if config.option.pylama and path.ext == '.py':
-        return PylamaItem(path, parent)
+    if config.option.pylama and path.ext == ".py":
+        return PylamaItem.from_parent(parent, fspath=path)
 
 
 class PylamaError(Exception):
-    """ indicates an error during pylama checks. """
+    """indicates an error during pylama checks."""
 
 
 class PylamaItem(pytest.Item, pytest.File):
-
-    def __init__(self, path, parent):
-        super(PylamaItem, self).__init__(path, parent)
+    def __init__(self, fspath, parent):
+        super(PylamaItem, self).__init__(fspath, parent)
         self.add_marker("pycodestyle")
         self.cache = None
         self._pylamamtimes = None
 
+    def collect(self):
+        pass
+
     def setup(self):
-        if not getattr(self.config, 'cache', None):
+        if not getattr(self.config, "cache", None):
             return False
 
         self.cache = True
@@ -69,8 +74,18 @@ class PylamaItem(pytest.Item, pytest.File):
     def runtest(self):
         errors = check_file(self.fspath)
         if errors:
-            pattern = "%(filename)s:%(lnum)s:%(col)s: %(text)s"
-            out = "\n".join([pattern % e._info for e in errors])
+            out = "\n".join(
+                [
+                    DEFAULT_FORMAT.format(
+                        filename=err.filename,
+                        lnum=err.lnum,
+                        col=err.col,
+                        etype=err.type,
+                        text=err.text,
+                    )
+                    for err in errors
+                ]
+            )
             raise PylamaError(out)
 
         # update mtime only if test passed
@@ -85,11 +100,9 @@ class PylamaItem(pytest.Item, pytest.File):
 
 
 def check_file(path):
-    from pylama.main import parse_options, process_paths
-    from pylama.config import CURDIR
-
     options = parse_options()
     path = op.relpath(str(path), CURDIR)
     return process_paths(options, candidates=[path], error=False)
 
-# pylama:ignore=D,E1002,W0212,F0001
+
+# pylama:ignore=D,E1002,W0212,F0001,C0115,C0116
